This function launches the eAnalytics Shiny application, which provides interactive visualizations and analyses of energy data. The application includes features such as time series plots, motion charts, data tables, and geographic maps.
Examples
if (interactive()) {
eAnalytics()
}